%{!?upstream_version: %global upstream_version %{version}%{?milestone}}
%global pypi_name paunch

%global common_desc \
Library and utility to launch and manage containers using YAML based configuration data.

Name:       python-%{pypi_name}
Version:    2.5.3
Release:    7%{?dist}
Summary:    Library and utility to launch and manage containers using YAML based configuration data

License:    ASL 2.0
URL:        http://pypi.python.org/pypi/%{pypi_name}
Source0:    https://tarballs.openstack.org/%{pypi_name}/%{pypi_name}-%{upstream_version}.tar.gz
Source10:   paunch-container-shutdown
Source11:   paunch-container-shutdown.service
Source12:   91-paunch-container-shutdown.preset
Source13:   netns-placeholder.service
Source14:   91-netns-placeholder.preset

#patches_ignore=DROP-IN-RPM
#patches_base=2.5.3
Patch0001: 0001-Revert-Check-if-volume-paths-exist-before-executing-.patch
Patch0002: 0002-Add-cpuset-cpus-support.patch
Patch0003: 0003-Allow-to-set-limit-memory-on-containers.patch
Patch0004: 0004-Allow-to-limit-cgroup-cpu-shares.patch
Patch0005: 0005-Fix-logging-to-stdout-and-file-in-classes-commands.patch
Patch0006: 0006-Log-to-a-file-by-default-unless-debugging.patch
Patch0007: 0007-Check-if-container-is-running-before-doing-an-exec.patch
Patch0008: 0008-Fix-discovering-container-names.patch
Patch0009: 0009-Do-not-force-remove-containers.patch
Patch0010: 0010-Fix-constraints-url.patch
Patch0011: 0011-Don-t-set-cpuset_cpus-if-empty.patch
Patch0012: 0012-Do-not-set-cpuset-cpus-if-cconfig-cpuset_cpus-all.patch
Patch0013: 0013-Fix-labels-to-take-multiple-values.patch
Patch0014: 0014-builder-include-environment-when-running-an-exec.patch
Patch0015: 0015-Cleanup-containers-in-the-same-loop-as-they-are-crea.patch
Patch0016: 0016-Process-labels-before-building-container-run-args.patch
Patch0017: 0017-Fix-return-results-on-cmd-failure-and-error-msgs.patch
Patch0018: 0018-queens-only-Improve-volume-validation-unclean-backpo.patch

BuildArch:  noarch
BuildRequires:  python2-setuptools
BuildRequires:  python2-pbr
BuildRequires:  python2-devel
BuildRequires:  python2-psutil
BuildRequires:  PyYAML
BuildRequires:  systemd-units

# test requires
BuildRequires:  python2-mock
BuildRequires:  python2-oslotest
BuildRequires:  python2-testrepository
BuildRequires:  python2-testscenarios
BuildRequires:  python2-tenacity >= 3.2.1

Requires:   python2-cliff
Requires:   docker
Requires:   python2-pbr
Requires:   python2-psutil
Requires:   PyYAML
Requires:   python2-tenacity >= 3.2.1
Requires:   findutils
Requires:   iproute

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
%{common_desc}

This package contains the paunch python library code and the command utility.

%package doc
Summary: Documentation for paunch library and utility

BuildRequires: python2-sphinx
BuildRequires: python2-oslo-sphinx
BuildRequires: openstack-macros

%description doc
%{common_desc}

This package contains auto-generated documentation.

%package tests
Summary: Tests for paunch library and utility

Requires:  python-%{pypi_name}
Requires:  python2-mock
Requires:  python2-oslotest
Requires:  python2-testrepository
Requires:  python2-testscenarios
Requires:  python2-tenacity >= 3.2.1

%description tests
%{common_desc}

This package contains library and utility tests.

%prep
%setup -q -n %{pypi_name}-%{upstream_version}

%patch0001 -p1
%patch0002 -p1
%patch0003 -p1
%patch0004 -p1
%patch0005 -p1
%patch0006 -p1
%patch0007 -p1
%patch0008 -p1
%patch0009 -p1
%patch0010 -p1
%patch0011 -p1
%patch0012 -p1
%patch0013 -p1
%patch0014 -p1
%patch0015 -p1
%patch0016 -p1
%patch0017 -p1
%patch0018 -p1

# Let's handle dependencies ourseleves
%py_req_cleanup

%build

%py2_build

%install
%py2_install

# Install shutdown script
install -p -D -m 755 %{SOURCE10} %{buildroot}%{_libexecdir}/paunch-container-shutdown

# Install systemd units
install -p -D -m 644 %{SOURCE11} %{buildroot}%{_unitdir}/paunch-container-shutdown.service

# Install systemd preset
install -p -D -m 644 %{SOURCE12} %{buildroot}%{_presetdir}/91-paunch-container-shutdown.preset

# Install netns unit
install -p -D -m 644 %{SOURCE13} %{buildroot}%{_unitdir}/netns-placeholder.service

# Install systemd preset for netns unit
install -p -D -m 644 %{SOURCE14} %{buildroot}%{_presetdir}/91-netns-placeholder.preset

# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
%{__python2} setup.py test

%post
%systemd_post paunch-container-shutdown.service
%systemd_post netns-placeholder.service

%preun
%systemd_preun paunch-container-shutdown.service
%systemd_preun netns-placeholder.service

%files
%doc README.rst
%license LICENSE
%{_bindir}/%{pypi_name}
%{python2_sitelib}/%{pypi_name}*
%{_libexecdir}/paunch-container-shutdown
%{_unitdir}/paunch-container-shutdown.service
%{_presetdir}/91-paunch-container-shutdown.preset
%{_unitdir}/netns-placeholder.service
%{_presetdir}/91-netns-placeholder.preset
%exclude %{python2_sitelib}/%{pypi_name}/tests

%files doc
%doc doc/build/html
%license LICENSE

%files tests
%license LICENSE
%{python2_sitelib}/%{pypi_name}/tests

%changelog
* Wed Jul 29 2020 Emilien Macchi <emilien@redhat.com> 2.5.3-7
- [queens-only] Improve volume validation (unclean backport) (rhbz#1847053)

* Mon May 18 2020 Alex Schultz <aschultz@redhat.com> 2.5.3-6
- Fix return results on cmd failure and error msgs (rhbz#1835828)

* Tue May 05 2020 Miguel Garcia <mgarciac@redhat.com> 2.5.3-5
- Process labels before building container run args
- Cleanup containers in the same loop as they are created
- builder: include environment when running an exec

* Wed Apr 08 2020 Emilien Macchi <emilien@redhat.com> 2.5.3-4
- Fix labels to take multiple values (rhbz#1813642)

* Thu Mar 19 2020 Emilien Macchi <emilien@redhat.com> 2.5.3-3
- Do not set cpuset-cpus if cconfig['cpuset_cpus'] == 'all' (rhbz#1813091)

* Thu Mar 19 2020 Emilien Macchi <emilien@redhat.com> 2.5.3-2
- Don't set cpuset_cpus if empty (rhbz#1813091)

* Wed Jan 29 2020 Miguel Garcia <mgarciac@redhat.com> 2.5.3-1
- Update to 2.5.3

* Thu Jan 23 2020 Bogdan Dobrelya <bdobreli@redhat.com> 2.5.0-11
- Do not force remove containers (rhbz#1790792)
- Fix discovering container names (rhbz#1790792)
- Check if container is running before doing an exec (rhbz#1790792)
- Log to a file by default, unless debugging (rhbz#1790792)
- Fix logging to stdout and file in classes/commands (rhbz#1790792)

* Fri Jan 03 2020 Alex Schultz <aschultz@redhat.com> 2.5.0-10
- Allow to limit cgroup cpu shares (rhbz#1787616)

* Thu Dec 12 2019 Alex Schultz <aschultz@redhat.com> 2.5.0-9
- Allow to set limit memory on containers (rhbz#1759677)
- Add --cpuset-cpus support (rhbz#1750781)
- Adjust tenacity mock (rhbz#1750781)

* Tue Nov 12 2019 Alex Schultz <aschultz@redhat.com> 2.5.0-8
- Actually activate new netns-placeholder unit (rhbz#1758547)
- Ensure we actually have /run/netns before starting containers (rhbz#1758547)

* Thu Sep 12 2019 Alex Schultz <aschultz@redhat.com> 2.5.0-6
- Revert "Check if volume paths exist before executing Docker." (rhbz#1751338)

* Tue Aug 13 2019 Grzegorz Grasza <xek@redhat.com> 2.5.0-5
- Check if volume paths exist before executing Docker. (rhbz#1732564)
- Fix comparing dictionaries for changes detection (rhbz#1705695)

* Tue Apr 23 2019 Jon Schlueter <jschluet@redhat.com> 2.5.0-4
- Allow configuring security options (rhbz#1701432)

* Mon Oct 15 2018 Jon Schlueter <jschluet@redhat.com> 2.5.0-3
- Make sure paunch-container-shutdown stops before pacemaker (rhbz#1628705)

* Thu Jul 05 2018 Alex Schultz <aschultz@redhat.com> 2.5.0-2
- Add paunch container shutdown service (rhbz#1597797)

* Tue Apr 10 2018 Jon Schlueter <jschluet@redhat.com> 2.5.0-1
- Update to 2.5.0

* Tue Mar 27 2018 Jon Schlueter <jschluet@redhat.com> 2.4.0-1
- Update to 2.4.0

* Mon Mar 05 2018 RDO <dev@lists.rdoproject.org> 2.3.0-1
- Update to 2.3.0

